@@ -1,9 +1,18 @@
 from __future__ import absolute_import
+from ciscoconfparse.ciscoconfparse import __author_email__
+from ciscoconfparse.ciscoconfparse import __author__
+from ciscoconfparse.ciscoconfparse import __license__
+from ciscoconfparse.ciscoconfparse import __version__
 from ciscoconfparse.ciscoconfparse import *
 from ciscoconfparse.ccp_util import *
 
 """ __init__.py - Parse, Query, Build, and Modify IOS-style configurations
-     Copyright (C) 2007-2021 David Michael Pennington
+
+     Copyright (C) 2020-2021 Cisco Systems and David Michael Pennington
+     Copyright (C) 2019      ThousandEyes and David Michael Pennington
+     Copyright (C) 2012-2019 Samsung Data Services and David Michael Pennington
+     Copyright (C) 2011-2012 Dell Computer Corp. and David Michael Pennington
+     Copyright (C) 2007-2011 David Michael Pennington and David Michael Pennington
 
      This program is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
