@@ -9,6 +9,29 @@ sys.path.insert(0, "..")
 import pytest
 from ciscoconfparse.ciscoconfparse import CiscoConfParse
 
+r""" conftest.py - Parse, Query, Build, and Modify IOS-style configs
+
+     Copyright (C) 2020-2021 Cisco Systems and David Michael Pennington
+     Copyright (C) 2019      ThousandEyes and David Michael Pennington
+     Copyright (C) 2015-2019 Samsung Data Services and David Michael Pennington
+
+     This program is free software: you can redistribute it and/or modify
+     it under the terms of the GNU General Public License as published by
+     the Free Software Foundation, either version 3 of the License, or
+     (at your option) any later version.
+
+     This program is distributed in the hope that it will be useful,
+     but WITHOUT ANY WARRANTY; without even the implied warranty of
+     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+     GNU General Public License for more details.
+
+     You should have received a copy of the GNU General Public License
+     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+     If you need to contact the author, you can do so by emailing:
+     mike [~at~] pennington [/dot\] net
+"""
+
 
 c01 = """policy-map QOS_1
  class GOLD
@@ -1132,17 +1155,17 @@ interface Ethernet1/10
 """.splitlines()
 
 
-@pytest.yield_fixture(scope="session")
+@pytest.fixture(scope="session")
 def c01_default_gigethernets(request):
     yield config_c01_default_gige
 
 
-@pytest.yield_fixture(scope="session")
+@pytest.fixture(scope="session")
 def c01_insert_serial_replace(request):
     yield config_c01_insert_serial_replace
 
 
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_c01(request):
     """Preparsed c01"""
     parse_c01 = CiscoConfParse(c01, factory=False)
@@ -1150,7 +1173,7 @@ def parse_c01(request):
     yield parse_c01
 
 
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_c01_factory(request):
     """Preparsed c01 with factory option"""
     parse_c01_factory = CiscoConfParse(c01, factory=True)
@@ -1158,7 +1181,7 @@ def parse_c01_factory(request):
     yield parse_c01_factory
 
 
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_c02(request):
     """Preparsed c02"""
     parse_c02 = CiscoConfParse(c02, factory=False)
@@ -1166,7 +1189,7 @@ def parse_c02(request):
     yield parse_c02
 
 
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_c02_factory(request):
     """Preparsed c02"""
     parse_c02 = CiscoConfParse(c02, factory=True)
@@ -1175,7 +1198,7 @@ def parse_c02_factory(request):
 
 
 ## parse_c03 yields configs/sample_01.ios
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_c03(request):
     """Preparsed c03"""
     parse_c03 = CiscoConfParse(c03, factory=False)
@@ -1184,7 +1207,7 @@ def parse_c03(request):
 
 
 ## parse_c03_factory yields configs/sample_01.ios
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_c03_factory(request):
     """Preparsed c01 with factory option"""
     parse_c03_factory = CiscoConfParse(c03, factory=True)
@@ -1193,7 +1216,7 @@ def parse_c03_factory(request):
 
 
 ## parse_j01 yields configs/sample_01.junos
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_j01(request):
     """Preparsed j01"""
     parse_j01 = CiscoConfParse(j01, syntax="junos", comment="#!", factory=False)
@@ -1202,7 +1225,7 @@ def parse_j01(request):
 
 
 ## parse_j01_factory yields configs/sample_01.junos
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_j01_factory(request):
     """Preparsed j01 with factory option"""
     parse_j01_factory = CiscoConfParse(j01, syntax="junos", comment="#!", factory=True)
@@ -1211,7 +1234,7 @@ def parse_j01_factory(request):
 
 
 ## parse_a01 yields the asa configuration
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_a01(request):
     """Preparsed a01"""
     parse_a01_factory = CiscoConfParse(a01, syntax="asa", factory=False)
@@ -1220,7 +1243,7 @@ def parse_a01(request):
 
 
 ## parse_a01_factory yields the asa configuration
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_a01_factory(request):
     """Preparsed a01 with factory option"""
     parse_a01_factory = CiscoConfParse(a01, syntax="asa", factory=True)
@@ -1229,14 +1252,14 @@ def parse_a01_factory(request):
 
 
 ## config_a02 yields an asa configuration
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def config_a02(request):
     """Unparsed a02"""
     yield a02
 
 
 ## parse_a02 yields an asa configuration
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_a02(request):
     """Preparsed a02"""
     parse_a02_factory = CiscoConfParse(a02, syntax="asa", factory=False)
@@ -1245,7 +1268,7 @@ def parse_a02(request):
 
 
 ## parse_a02_factory yields an asa configuration
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_a02_factory(request):
     """Preparsed a02 with factory option"""
     parse_a02_factory = CiscoConfParse(a02, syntax="asa", factory=True)
@@ -1254,14 +1277,14 @@ def parse_a02_factory(request):
 
 
 ## config_n02 yields a nexus configuration
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def config_n01(request):
     """Unparsed n01"""
     yield n01
 
 
 ## parse_n01 yields a nexus configuration
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_n01(request):
     """Preparsed n01"""
     parse_n01_factory = CiscoConfParse(n01, syntax="nxos", factory=False)
@@ -1270,7 +1293,7 @@ def parse_n01(request):
 
 
 ## parse_n01_factory yields a nexus configuration
-@pytest.yield_fixture(scope="function")
+@pytest.fixture(scope="function")
 def parse_n01_factory(request):
     """Preparsed n01 with factory option"""
     parse_n01_factory = CiscoConfParse(n01, syntax="nxos", factory=True)
@@ -1282,7 +1305,7 @@ def parse_n01_factory(request):
 @pytest.mark.skipif(
     "windows" in platform.system().lower(), reason="No Windows MockSSH support"
 )
-@pytest.yield_fixture(scope="session")
+@pytest.fixture(scope="session")
 def cisco_sshd_mocked(request):
     """Mock Cisco IOS SSH"""
     from fixtures.devices.mock_cisco import start_cisco_mock, stop_cisco_mock
